PackedPoint class final

Example of a packed struct with no padding

Inheritance
Implemented types
Available extensions
Annotations

Constructors

PackedPoint()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x ↔ int
getter/setter pair
y ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() → ByteBuffer
Serializes the PackedPoint struct to a ByteBuffer.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

alloc() → Pointer<PackedPoint>
Allocates memory for a new PackedPoint struct.
create() → PackedPoint
Creates a new PackedPoint instance.
override
deserialize(ByteBuffer buffer) → PackedPoint
Deserializes a ByteBuffer to a PackedPoint struct.