Point class final

Example struct implementation showing basic usage

Inheritance
Implemented types
Available extensions

Constructors

Point()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
debugFields → Map<String, dynamic>
Get debug fields for printing
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
protoFields → List<ProtoField>

Available on Point, provided by the PointProtobuf extension

Get field descriptors for the Point struct.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
structSize → int
Get struct size in bytes
no setteroverride
x ↔ int
getter/setter pair
y ↔ int
getter/setter pair

Methods

calculateSize() → int

Available on Point, provided by the PointProtobuf extension

Calculate size needed for serialization.
deserializeFromProto(ByteBuffer buffer) → void

Available on Point, provided by the PointProtobuf extension

Deserialize the Point from Protocol Buffer format.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() → ByteBuffer
Serializes the Point struct to a ByteBuffer.
serializeToProto() → ByteBuffer

Available on Point, provided by the PointProtobuf extension

Serialize the Point to Protocol Buffer format.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

alloc() → Pointer<Point>
Allocates memory for a new Point struct.
create() → Point
Creates a new Point instance.
override
deserialize(ByteBuffer buffer) → Point
Deserializes a ByteBuffer to a Point struct.