StructField class

Main annotation for specifying struct field properties

Constructors

StructField(int offset, {int size = 1, bool packed = false})
Constructs a StructField annotation.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
offset → int
final
packed → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited