StructScope class

A scope-based memory manager for automatic cleanup

Constructors

StructScope()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

allocComplexStruct() → Pointer<ComplexStruct>
Allocate single ComplexStruct
allocDataUnion() → Pointer<DataUnion>
Allocate single DataUnion
allocPoint() → Pointer<Point>
Allocate single Point
allocPoints(int count) → Pointer<Point>
Allocate an array of Points
allocRectangle() → Pointer<Rectangle>
Allocate single Rectangle
allocTaggedUnion() → Pointer<TaggedUnion>
Allocate single TaggedUnion
dispose() → void
Free all allocated memory
free(Pointer<NativeType> ptr) → void
Manually free a pointer and remove it from cleanup
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(Pointer<NativeType> ptr) → void
Register an existing pointer for cleanup
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited