BaseStructPool class

A base class for managing a pool of structs

Implementers

Constructors

BaseStructPool({required int capacity})
Constructs a BaseStructPool with the given capacity.

Properties

allocated → int
Returns the number of allocated structs.
no setter
available → int
Returns the number of available slots in the pool.
no setter
capacity → int
Returns the total capacity of the pool.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isDisposed → bool
Returns whether the pool has been disposed.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

markDisposed() → void
Marks the pool as disposed.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited