DataUnion class final

Example union showing multiple ways to interpret the same memory

Inheritance
Implemented types
Available extensions

Constructors

DataUnion()

Properties

address → Pointer<T>

Available on T, provided by the UnionAddress extension

The memory address of the underlying data.
no setter
asBytes ↔ Array<Uint8>
getter/setter pair
asFloat ↔ double
getter/setter pair
asInt32 ↔ int
getter/setter pair
asInt64 ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

alloc() → Pointer<DataUnion>
Allocates memory for a DataUnion instance.
create() → DataUnion
Creates a DataUnion instance.
override