ProtoField class

Protocol Buffer field descriptor

Constructors

ProtoField(int number, WireType wireType, String name)
Constructs a ProtoField with the given number, wire type, and name.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the field.
final
number → int
The field number.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wireType → WireType
The wire type of the field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited