ProtobufSerializable class abstract interface

Protocol Buffer serialization interface

Properties

hashCode → int
The hash code for this object.
no setterinherited
protoFields → List<ProtoField>
Get field descriptors for the struct.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

calculateSize() → int
Calculate size needed for serialization.
deserializeFromProto(ByteBuffer buffer) → void
Deserialize from Protocol Buffer format.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serializeToProto() → ByteBuffer
Serialize to Protocol Buffer format.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited