StringStruct class final

Represents an example usage struct containing a string and a string array.

Inheritance
Implemented types
Available extensions

Constructors

StringStruct()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
name ↔ StructString
The name field as a StructString.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags ↔ StructStringArray
The tags field as a StructStringArray.
getter/setter pair

Methods

dispose() → void
Disposes the allocated memory for the struct.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create({int nameCapacity = 50, int tagsCapacity = 10, int tagStringCapacity = 20}) → Pointer<StringStruct>
Creates a new StringStruct with the given capacities.
override