StructStringArray class final

Represents a string array for struct fields.

Inheritance
Implemented types
Available extensions

Constructors

StructStringArray()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
capacity ↔ int
The capacity of the string array.
getter/setter pair
data ↔ Pointer<Pointer<Uint8>>
Pointer to the array of string data pointers.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
length ↔ int
The length of the string array.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringCapacity ↔ int
The capacity of each string in the array.
getter/setter pair

Methods

dispose() → void
Disposes the allocated memory for the string array.
getString(int index) → String
Gets the string value at the specified index.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setString(int index, String value) → void
Sets the string value at the specified index.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create(int arrayCapacity, int stringCapacity) → Pointer<StructStringArray>
Creates a new StructStringArray with the given capacities.
override