ComplexStruct class final

Complex struct example showing nested structs and arrays

Inheritance
Implemented types
Available extensions

Constructors

ComplexStruct()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
data ↔ Array<Int32>
The data array of the complex struct
getter/setter pair
end ↔ Point
The end point of the complex struct
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
The ID of the complex struct
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ Point
The start point of the complex struct
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() → ByteBuffer
Serializes the ComplexStruct to a ByteBuffer.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

alloc() → Pointer<ComplexStruct>
Allocates memory for a ComplexStruct instance.
create() → ComplexStruct
Creates a ComplexStruct instance.
override
deserialize(ByteBuffer buffer) → ComplexStruct
Deserializes a ComplexStruct from a ByteBuffer.