AlignedStruct class final

Example of a struct with custom alignment

Inheritance
Implemented types
Available extensions

Constructors

AlignedStruct()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
byteField ↔ int
getter/setter pair
doubleField ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intField ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortField ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

alloc() → Pointer<AlignedStruct>
Allocates memory for an AlignedStruct instance
free(Pointer<AlignedStruct> ptr) → void
Frees the allocated memory for an AlignedStruct instance