AlignmentUtils class

Helper functions for alignment calculations

Constructors

AlignmentUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

alignOffset(int offset, int alignment) → int
Get the next aligned offset
calculateAlignedSize(int size, int alignment) → int
Calculate total size with alignment
calculatePadding(int offset, int alignment) → int
Calculate padding needed to align to the given boundary
isAligned(int offset, int alignment) → bool
Verify if an offset is properly aligned