ByteOrder class

Annotation for specifying field endianness

Constructors

ByteOrder(StructEndian endian)
Constructs a ByteOrder annotation with the given endianness
const

Properties

endian → StructEndian
The endianness to be applied to the field
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited