EndianUtils class

Helper for endian conversion

Constructors

EndianUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

hostToNetwork32(int value) → int
Convert host to network byte order (if needed)
networkToHost32(int value) → int
Convert network to host byte order (if needed)
swap16(int value) → int
Swap bytes for 16-bit value
swap32(int value) → int
Swap bytes for 32-bit value
swap64(int value) → int
Swap bytes for 64-bit value